@@ -525,7 +525,7 @@ class Auth:
                 LOG.error(error_msg)
                 return CustomError(
                     message=error_msg,
-                    reasons=[f"{ex}"],
+                    reasons=["Incorrect email domain"],
                 )
         except Exception as ex:
             LOG.error(error_msg)
